Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type App ¶
type MouseEvent ¶
type MouseEvent struct {
X, Y int
Type MouseEventType
}
type Rectangle ¶
type Rectangle struct {
X int // X coordinate of the top-left corner
Y int // Y coordinate of the top-left corner
Width int // Width of the rectangle
Height int // Height of the rectangle
}
func (Rectangle) IntersectsPoint ¶
type StyleField ¶
type StyleField int
const ( Margin StyleField = iota Mt Mb Ml Mr Padding Pt Pb Pl Pr W H X Y Bg Color Font Text All )
type StylesModification ¶
type TransitionProperty ¶
type TransitionProperty struct {
TimingFunction TimingFunction
Delay int //in ms
Duration int //in ms
}
type Transitions ¶
type Transitions = map[StyleField]TransitionProperty
Click to show internal directories.
Click to hide internal directories.